@@ -1,6 +1,6 @@
 .First.lib <- function(lib, pkg) {
-  cat("Locfit for R 1.2.0.\n")
-  cat("2000-12-19.\n")
+  cat("Locfit for R 1.3.0.\n")
+  cat("August 3, 2000.\n")
   library.dynam("locfit", pkg, lib)
   invisible(NULL)
 }
